#!/bin/bash

__CORE_PATTERN=""

function save_core_pattern {
    __CORE_PATTERN=$(< /proc/sys/kernel/core_pattern)
}

function exit_with_code {
    echo ${1}
    exit ${2}
}

function restore_core_pattern {
    echo ${__CORE_PATTERN} > /proc/sys/kernel/core_pattern
}

function endoftime {
    TIMEOUT=$((TIMEOUT-1))
    if [ $((TIMEOUT)) == 0 ]; then
        return 0
    fi
    return 1
}

function check {
    if [[ ${RESULT} =~ ${1} ]]; then
        return 0
    fi
    exit_with_code "FAIL: not found ${1} in ${RESULT}" 1
}

function tzplatform_var {
    VAL=`tzplatform-get ${1}`
    if [ $? == 0 ]; then
        echo $VAL | cut -d'=' -f2
        return 0
    fi
    return 1
}

function clean_crash_root {
    export CRASH_ROOT_PATH=`tzplatform_var TZ_SYS_CRASH`

    killall crash-manager
    killall minicoredumper

    sleep 1

    if [ -z ${CRASH_ROOT_PATH} ]; then
        exit_with_code "Couldn't get TZ_SYS_CRASH or TZ_SYS_CRASH is empty" 1
    fi

    if [ ! -d ${CRASH_ROOT_PATH} ]; then
        exit_with_code "${CRASH_ROOT_PATH} does not exist" 1
    fi

    rm -rf ${CRASH_ROOT_PATH}/*
}

function wait_for_file {
    TIMEOUT=240
    while [ ! -f ${1} ];
    do
        if endoftime; then
            exit_with_code "FAIL: ${1} does not exist" 1
        else
            sleep 1
        fi
    done
    return 0
}

function wait_for_app {
    TIMEOUT=240
    while true;
    do
        if ! pidof ${1} 1> /dev/null 2>&1; then
            break;
        fi
        if endoftime; then
            exit_with_code "FAIL: ${1} is still running" 1
        else
            sleep 1
        fi
    done
    return 0
}

function backup_file {
    cp ${1} ${1}.backup
}

function restore_file {
    mv ${1}.backup ${1}
}
